import { UserPoolSESOptions } from 'aws-cdk-lib/aws-cognito';
import { AuthProps, TriggerEvent, UserPoolSnsOptions } from '@aws-amplify/auth-construct';
import { AuthResources, AuthRoleName, ConstructFactory, ConstructFactoryGetInstanceProps, FunctionResources, ResourceAccessAcceptorFactory, ResourceProvider, StackProvider } from '@aws-amplify/plugin-types';
import { AuthAccessGenerator, AuthLoginWithFactoryProps, CustomEmailSender, CustomSmsSender, Expand } from './types.js';
export type BackendAuth = ResourceProvider<AuthResources> & ResourceAccessAcceptorFactory<AuthRoleName | string> & StackProvider;
export type AmplifyAuthProps = Expand<Omit<AuthProps, 'outputStorageStrategy' | 'loginWith' | 'senders'> & {
    /**
     * Specify how you would like users to log in. You can choose from email, phone, and even external providers such as LoginWithAmazon.
     */
    loginWith: Expand<AuthLoginWithFactoryProps>;
    /**
     * Configure custom auth triggers
     * @see https://docs.amplify.aws/react/build-a-backend/auth/customize-auth-lifecycle/triggers/
     */
    triggers?: Partial<Record<TriggerEvent, ConstructFactory<ResourceProvider<FunctionResources>>>>;
    /**
     * Configure access to auth for other Amplify resources
     * @see https://docs.amplify.aws/react/build-a-backend/auth/grant-access-to-auth-resources/
     * @example
     * access: (allow) => [allow.resource(postConfirmation).to(["addUserToGroup"])]
     * @example
     * access: (allow) => [allow.resource(groupManager).to(["manageGroups"])]
     */
    access?: AuthAccessGenerator;
    /**
     * Configure email sender options
     */
    senders?: {
        email?: Pick<UserPoolSESOptions, 'fromEmail' | 'fromName' | 'replyTo'> | CustomEmailSender;
        sms?: UserPoolSnsOptions | CustomSmsSender;
    };
}>;
/**
 * Singleton factory for AmplifyAuth that can be used in Amplify project files.
 *
 * Exported for testing purpose only & should NOT be exported out of the package.
 */
export declare class AmplifyAuthFactory implements ConstructFactory<BackendAuth> {
    private readonly props;
    private readonly importStack;
    static factoryCount: number;
    readonly provides = "AuthResources";
    private generator;
    /**
     * Set the properties that will be used to initialize AmplifyAuth
     */
    constructor(props: AmplifyAuthProps, importStack?: string | undefined);
    /**
     * Get a singleton instance of AmplifyAuth
     */
    getInstance: (getInstanceProps: ConstructFactoryGetInstanceProps) => BackendAuth;
}
/**
 * Provide the settings that will be used for authentication.
 */
export declare const defineAuth: (props: AmplifyAuthProps) => ConstructFactory<BackendAuth>;
//# sourceMappingURL=factory.d.ts.map